@@ -258,7 +258,7 @@ static struct running_shell {
     pid_t shell_pid;
     int shell_pipe;
     POOL *shell_pool;
-    char *shell_name;
+    const char *shell_name;
     CWidget *w;
     int killme;
 } running_shell[MAX_RUNNING_SHELLS];
@@ -271,7 +271,7 @@ static void kill_process (pid_t p)
 
 
 /* one of these must be non-zero */
-static int find_shell (pid_t p, char *name, CWidget * w)
+static int find_shell (pid_t p, const char *name, CWidget * w)
 {
     int i;
     for (i = 0; i < MAX_RUNNING_SHELLS; i++) {
@@ -289,7 +289,7 @@ static int find_shell (pid_t p, char *name, CWidget * w)
     return -1;
 }
 
-static int new_shell (char *name)
+static int new_shell (const char *name)
 {
     int i;
     i = find_shell (0, name, 0);
@@ -350,7 +350,7 @@ static int kill_shell (pid_t p, char *name, CWidget * w)
     return i;
 }
 
-static int restart_shell (pid_t p, char *name, CWidget * w)
+static int restart_shell (pid_t p, const char *name, CWidget * w)
 {
     int i;
     i = find_shell (p, name, w);
@@ -503,7 +503,7 @@ static void shell_pool_update (int fd, fd_set * reading, fd_set * writing, fd_se
 }
 
 /* draws a textbox dialog for showing the shells output */
-static void shell_display_output (char *text, const char *heading, int (*select_line_callback) (CWidget *, XEvent *, CEvent *), char *name)
+static void shell_display_output (char *text, const char *heading, int (*select_line_callback) (CWidget *, XEvent *, CEvent *), const char *name)
 {
     int i;
     if (!text)
@@ -554,7 +554,7 @@ static char *hme_i (char *h, int i)
 }
 
 /* returns non-zero on error */
-int execute_background_display_output (char *title, char *s, char *name)
+int execute_background_display_output (const char *title, const char *s, const char *name)
 {
     char *argv[] =
     {0, 0};
@@ -680,6 +680,7 @@ static int run_shell (WEdit * e, struct shell_cmd *s, char *cmdline_options, cha
     int i;
 
     i = find_shell (0, name, 0);
+    if (i >= 0)
     if (!(s->options & (SHELL_OPTION_DISPLAY_STDOUT_CONTINUOUS |
 			SHELL_OPTION_DISPLAY_STDERR_CONTINUOUS)))	/* --> these kill any running script automatically */
 	if (running_shell[i].shell_pid) {
@@ -1192,7 +1193,7 @@ static char *get_a_line (void *data, int line)
     return t;
 }
 
-int script_list_box_dialog (Window parent, int x, int y, char *heading)
+int script_list_box_dialog (Window parent, int x, int y, const char *heading)
 {
     int n;
 
@@ -1318,7 +1319,7 @@ static int list_jobs (void)
     if (i >= 0) {
 	j = get_job (e, i);
 	if (j)
-	    shell_output_kill_job (e, j->pid);
+	    shell_output_kill_job (e, j->pid, 1);
     }
     return 0;
 }
