@@ -2475,7 +2475,7 @@ char *edit_get_text_from_selection_history (Window parent, int x, int y, int col
     }
     i = (current_selection + i + 1) % NUM_SELECTION_HISTORY;
     *len = selection_history[i].len;
-    return selection_history[i].text;
+    return (char *) selection_history[i].text;
 }
 
 void edit_paste_from_history (WEdit * edit)
@@ -2486,7 +2486,7 @@ void edit_paste_from_history (WEdit * edit)
     edit_update_curs_col (edit);
     edit_update_curs_row (edit);
     s = edit_get_text_from_selection_history (WIN_MESSAGES, max (20, edit->num_widget_columns - 5), 10, &len);
-    paste_text (edit, s, len);
+    paste_text (edit, (unsigned char *) s, len);
     edit->force |= REDRAW_COMPLETELY;
 }
 
