@@ -36,7 +36,7 @@
 #include <locale.h>
 #endif
 
-#include "libgettext.h"
+#include "gettext.h"
 
 #define _(String) gettext (String)
 
